# Email Service

_Send emails via Kafka messaging._

## WIP: Features

- [x] Publish/Consumer
- [x] Send emails
- [ ] Template support
- [x] Attachment support
- [x] CC Support
- [x] BCC Support

### Usage
See [example_publisher](example_publisher)

### Notes

How to implement configurable templates?

## Development

For help getting started developing check [DEVELOPMENT.md](DEVELOPMENT.md)
